<div class="col-xs-6 col-sm-12 col-md-12 col-lg-12">
    <h1>{group_name}</h1>
</div>
<div class="col-xs-6 col-sm-6 col-md-6 col-lg-12">
    <?php foreach ($items as $item) : ?>
        <div class="col-xs-6 col-sm-6 col-md-4 col-lg-4">
            <div class="thumbnail">
                <a href="<?= $item['url'] ?>" class="">
                    <img alt="" src="<?= $this->image->getImage($item['photo'], 405, 405) ?>" />
                </a>
                <div class="caption">
                    <h3><a href="<?= $item['url'] ?>" class="center-block"><?= $item['name'] ?></a></h3>
                    <span class="center-block"><?= $item['short_desc'] ?></span>
                    <span>C$<?= $item['price'] ?></span>
                    <button type="button" class="btn btn-default center-block"><?= $this->lang->line('add to basket') ?></button>
                </div>
            </div>
        </div>
    <?php endforeach; ?>
</div>
