<table class="table">
    <tr>
        <th><?= $this->lang->line('Options') ?></th>
        <?php foreach ($title as $el): ?>
            <th><?= $el ?></th>
        <?php endforeach; ?>
    </tr>
    <?php foreach ($data as $item): ?>
        <tr>
            <td><?= $item['title'][$id_lan] ?></td>
            <?php foreach ($item['option'] as $opt): ?>
                <td><?= $opt['input'] ?></td>
            <?php endforeach; ?>
        </tr>
    <?php endforeach; ?>
</table>