<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Product_admin extends MX_Controller
{

    public function manufacturer()
    {
        $this->load->model('product/crud_manufacturer');

        return array('content' => $this->crud_manufacturer->render(), 'title' => $this->lang->line('Manufacturers'));
    }

    public function attributes()
    {
        $this->load->model('product/crud_attr');

        return array('content' => $this->crud_attr->render(), 'title' => $this->lang->line('Attributes'));
    }

    public function groups()
    {
        $this->load->model('product/crud_group');

        return array('content' => $this->crud_group->render(), 'title' => $this->lang->line('Product templates'));
    }

    public function icons()
    {
        $this->load->model('product/crud_icon');

        return array('content' => $this->crud_icon->render(), 'title' => $this->lang->line('Product icons'));
    }

    public function products()
    {
        $this->load->model('product/crud_product');

        return array('content' => $this->crud_product->render(), 'title' => $this->lang->line('Products'));
    }

}
