CREATE TABLE IF NOT EXISTS `product_translate` 
(`id_product_translate` int(11) NOT NULL AUTO_INCREMENT, 
`id_product` int(11), 
`id_lan` int(11), 
`name` varchar(255) CHARACTER SET utf8 NOT NULL, 
`short_desc` varchar(255) CHARACTER SET utf8 NOT NULL, 
`description` text CHARACTER SET utf8 NOT NULL, 
PRIMARY KEY (`id_product_translate`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `product_attr_translate` 
(`id_product_attr_translate` int(11) NOT NULL AUTO_INCREMENT, 
`id_product_attr` int(11), 
`id_lan` int(11), 
`name` varchar(255) CHARACTER SET utf8 NOT NULL, 
`options` text CHARACTER SET utf8, 
PRIMARY KEY (`id_product_attr_translate`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `product_manufacturer_translate` 
(`id_product_manufacturer_translate` int(11) NOT NULL AUTO_INCREMENT, 
`id_product_manufacturer` int(11), 
`id_lan` int(11), 
`name` varchar(255) CHARACTER SET utf8 NOT NULL, 
PRIMARY KEY (`id_product_manufacturer_translate`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `product_icon_translate` 
(`id_product_icon_translate` int(11) NOT NULL AUTO_INCREMENT, 
`id_product_icon` int(11), 
`id_lan` int(11), 
`name` varchar(255) CHARACTER SET utf8 NOT NULL, 
PRIMARY KEY (`id_product_icon_translate`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;